;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "russian-calendar" "20251026.1548"
  "Russian holidays and conferences. Updated 2025-09-30."
  '((emacs "29.4"))
  :url "https://github.com/Anoncheg1/emacs-russian-calendar"
  :commit "95c7d95476f793f11033923b3e2c1b0c98d10f8b"
  :revdesc "95c7d95476f7"
  :keywords '("calendar" "holidays"))
